@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Deep::JType;
 # ABSTRACT: Test::Deep helpers for JSON::Typist data
-$Test::Deep::JType::VERSION = '0.005';
+$Test::Deep::JType::VERSION = '0.006';
 use JSON::PP ();
 use JSON::Typist ();
 use Test::Deep 1.126 (); # LeafWrapper, as_test_deep_cmp
@@ -50,7 +50,7 @@ our @EXPORT = qw( jcmp_deeply jstr jnum jbool jtrue jfalse );
 
 sub jcmp_deeply {
   local $Test::Builder::Level = $Test::Builder::Level + 1;
-  local $Test::Deep::LeafWrapper = \&Test::Deep::str;
+  local $Test::Deep::LeafWrapper = sub { Test::Deep::JType::_String->new(@_) },
   Test::Deep::cmp_deeply(@_);
 }
 
@@ -113,9 +113,47 @@ my $FALSE = jbool(0);
 sub jtrue  { $TRUE  }
 sub jfalse { $FALSE }
 
+{
+  package
+    Test::Deep::JType::_String;
+
+  use Test::Deep::Cmp;
+
+  sub init
+  {
+    my $self = shift;
+
+    $self->{val} = shift;
+  }
+
+  sub descend
+  {
+    my $self = shift;
+    my $got = shift();
+
+    # If either is undef but not both this is a failure where
+    # as Test::Deep::String would just stringify the undef,
+    # throw a warning, and pass
+    if (defined($got) xor defined($self->{val})) {
+      return 0;
+    }
+
+    return $got eq $self->{val};
+  }
+
+  sub diag_message
+  {
+    my $self = shift;
+
+    my $where = shift;
+
+    return "Comparing $where as a string";
+  }
+}
+
 {
   package Test::Deep::JType::jstr;
-$Test::Deep::JType::jstr::VERSION = '0.005';
+$Test::Deep::JType::jstr::VERSION = '0.006';
 use overload
     '""'    => sub {
       Carp::confess("can't use valueless jstr() as a string")
@@ -141,7 +179,7 @@ use overload
 
 {
   package Test::Deep::JType::jnum;
-$Test::Deep::JType::jnum::VERSION = '0.005';
+$Test::Deep::JType::jnum::VERSION = '0.006';
 use overload
     '0+'    => sub {
       Carp::confess("can't use valueless jnum() as a number")
@@ -167,7 +205,7 @@ use overload
 
 {
   package Test::Deep::JType::jbool;
-$Test::Deep::JType::jbool::VERSION = '0.005';
+$Test::Deep::JType::jbool::VERSION = '0.006';
 use overload
     'bool'    => sub {
       Carp::confess("can't use valueless jbool() as a bool")
@@ -209,7 +247,7 @@ Test::Deep::JType - Test::Deep helpers for JSON::Typist data
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 OVERVIEW
 
